from typing import List
from typing import Optional

from h2o_secure_store.clients.auth.token_api_client import TokenApiClient
from h2o_secure_store.clients.connection_config import ConnectionConfig
from h2o_secure_store.clients.token_source.page import TokenSourcesPage
from h2o_secure_store.clients.token_source.token_source import TokenSource
from h2o_secure_store.clients.token_source.token_source import from_api_object
from h2o_secure_store.exception import CustomApiException
from h2o_secure_store.gen import ApiException
from h2o_secure_store.gen import Configuration
from h2o_secure_store.gen.api.token_source_service_api import TokenSourceServiceApi
from h2o_secure_store.gen.model.v1_list_token_sources_response import (
    V1ListTokenSourcesResponse,
)
from h2o_secure_store.gen.model.v1_token_source import V1TokenSource


class TokenSourceClient:
    """TokenSourceClient manages TokenSources."""

    def __init__(
            self,
            connection_config: ConnectionConfig,
            verify_ssl: bool = True,
            ssl_ca_cert: Optional[str] = None,
    ):
        configuration = Configuration(host=connection_config.server_url)
        configuration.verify_ssl = verify_ssl
        configuration.ssl_ca_cert = ssl_ca_cert

        with TokenApiClient(
                configuration, connection_config.token_provider
        ) as api_client:
            self.api_instance = TokenSourceServiceApi(api_client)

    def create_token_source(
            self,
            oauth_client_id: str,
            redirect_uri: str = "",
            token_source_id: str = "",
    ) -> TokenSource:
        """Creates a TokenSource.

        Args:
            oauth_client_id (str): OAuthClient ID.
            token_source_id (str, optional): The ID to use for the TokenSource, which will become the final component of the token source's resource name.
                If left unspecified, the server will generate a random value.
                This value must:

                - contain 1-63 characters
                - contain only lowercase alphanumeric characters or hyphen ('-')
                - start with an alphabetic character
                - end with an alphanumeric character
            redirect_uri (str, optional): The URI to redirect to after the user has successfully logged in.

        Returns:
            TokenSource: TokenSource object.
        """
        api_object = V1TokenSource(
            redirect_uri=redirect_uri,
        )
        created_api_object: V1TokenSource

        try:
            created_api_object = self.api_instance.token_source_service_create_token_source(
                parent=f"oauthClients/{oauth_client_id}", token_source=api_object, token_source_id=token_source_id
            ).token_source
        except ApiException as e:
            raise CustomApiException(e)
        return from_api_object(api_object=created_api_object)

    def get_token_source(self, oauth_client_id: str, token_source_id: str) -> TokenSource:
        """Returns a TokenSource.

        Args:
            oauth_client_id (str): OAuthClient ID.
            token_source_id (str): TokenSource ID.

        Returns:
            TokenSource: TokenSource object.
        """
        api_object: V1TokenSource

        try:
            api_object = self.api_instance.token_source_service_get_token_source(
                name_3=self.build_resource_name(oauth_client_id=oauth_client_id, token_source_id=token_source_id)
            ).token_source
        except ApiException as e:
            raise CustomApiException(e)

        return from_api_object(api_object=api_object)

    def list_token_sources(
            self,
            oauth_client_id: str,
            page_size: int = 0,
            page_token: str = "",
    ) -> TokenSourcesPage:
        """Lists TokenSources.

        Args:
            oauth_client_id (str): OAuthClient ID.
            page_size (int): Maximum number of TokenSources to return in a response.
                If unspecified (or set to 0), at most 50 TokenSources will be returned.
                The maximum value is 1000; values above 1000 will be coerced to 1000.
            page_token (str): Page token.
                Leave unset to receive the initial page.
                To list any subsequent pages use the value of 'next_page_token' returned from the TokenSourcesPage.

        Returns:
            TokenSourcesPage: TokenSourcesPage object.
        """
        list_response: V1ListTokenSourcesResponse

        try:
            list_response = (
                self.api_instance.token_source_service_list_token_sources(
                    parent=f"oauthClients/{oauth_client_id}",
                    page_size=page_size,
                    page_token=page_token,
                )
            )
        except ApiException as e:
            raise CustomApiException(e)

        return TokenSourcesPage(list_response)

    def list_all_token_sources(self, oauth_client_id: str) -> List[TokenSource]:
        """ Lists all TokenSources.

        Returns:
            List of TokenSource.
        """
        all_token_sources: List[TokenSource] = []
        next_page_token = ""
        while True:
            token_source_list = self.list_token_sources(
                oauth_client_id=oauth_client_id,
                page_size=0,
                page_token=next_page_token,
            )
            all_token_sources = all_token_sources + token_source_list.token_sources
            next_page_token = token_source_list.next_page_token
            if next_page_token == "":
                break

        return all_token_sources

    def delete_token_source(self, oauth_client_id: str, token_source_id: str) -> None:
        """Deletes a TokenSource.

        Args:
            oauth_client_id (str): OAuthClient ID.
            token_source_id (str): TokenSource ID.
        """
        try:
            self.api_instance.token_source_service_delete_token_source(
                name_2=self.build_resource_name(oauth_client_id=oauth_client_id, token_source_id=token_source_id)
            )
        except ApiException as e:
            raise CustomApiException(e)

    def delete_all_token_sources(self, oauth_client_id: str) -> None:
        """Delete all TokenSources."""
        for t in self.list_all_token_sources(oauth_client_id=oauth_client_id):
            self.delete_token_source(oauth_client_id=t.oauth_client_id, token_source_id=t.token_source_id)

    @staticmethod
    def build_resource_name(oauth_client_id: str, token_source_id: str) -> str:
        """Helper function for building resource name."""
        return f"oauthClients/{oauth_client_id}/tokenSources/{token_source_id}"



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/securestore/v1/secret_service.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from h2o_secure_store.gen.ai.h2o.securestore.v1 import secret_pb2 as ai_dot_h2o_dot_securestore_dot_v1_dot_secret__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ai/h2o/securestore/v1/secret_service.proto\x12\x15\x61i.h2o.securestore.v1\x1a\"ai/h2o/securestore/v1/secret.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/api/resource.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\"\xb1\x01\n\x13\x43reateSecretRequest\x12:\n\x06parent\x18\x01 \x01(\tB\"\xe2\x41\x01\x02\xfa\x41\x1b\x12\x19securestore.h2o.ai/SecretR\x06parent\x12;\n\x06secret\x18\x02 \x01(\x0b\x32\x1d.ai.h2o.securestore.v1.SecretB\x04\xe2\x41\x01\x02R\x06secret\x12!\n\tsecret_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\x08secretId\"M\n\x14\x43reateSecretResponse\x12\x35\n\x06secret\x18\x01 \x01(\x0b\x32\x1d.ai.h2o.securestore.v1.SecretR\x06secret\"J\n\x10GetSecretRequest\x12\x36\n\x04name\x18\x01 \x01(\tB\"\xe2\x41\x01\x02\xfa\x41\x1b\n\x19securestore.h2o.ai/SecretR\x04name\"J\n\x11GetSecretResponse\x12\x35\n\x06secret\x18\x01 \x01(\x0b\x32\x1d.ai.h2o.securestore.v1.SecretR\x06secret\"\xc1\x01\n\x12ListSecretsRequest\x12:\n\x06parent\x18\x01 \x01(\tB\"\xe2\x41\x01\x02\xfa\x41\x1b\x12\x19securestore.h2o.ai/SecretR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\x12\'\n\x0cshow_deleted\x18\x04 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0bshowDeleted\"\x95\x01\n\x13ListSecretsResponse\x12\x37\n\x07secrets\x18\x01 \x03(\x0b\x32\x1d.ai.h2o.securestore.v1.SecretR\x07secrets\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"M\n\x13\x44\x65leteSecretRequest\x12\x36\n\x04name\x18\x01 \x01(\tB\"\xe2\x41\x01\x02\xfa\x41\x1b\n\x19securestore.h2o.ai/SecretR\x04name\"M\n\x14\x44\x65leteSecretResponse\x12\x35\n\x06secret\x18\x01 \x01(\x0b\x32\x1d.ai.h2o.securestore.v1.SecretR\x06secret\"O\n\x15UndeleteSecretRequest\x12\x36\n\x04name\x18\x01 \x01(\tB\"\xe2\x41\x01\x02\xfa\x41\x1b\n\x19securestore.h2o.ai/SecretR\x04name\"O\n\x16UndeleteSecretResponse\x12\x35\n\x06secret\x18\x01 \x01(\x0b\x32\x1d.ai.h2o.securestore.v1.SecretR\x06secret2\xb7\x06\n\rSecretService\x12\xb4\x01\n\x0c\x43reateSecret\x12*.ai.h2o.securestore.v1.CreateSecretRequest\x1a+.ai.h2o.securestore.v1.CreateSecretResponse\"K\xda\x41\x17parent,secret,secret_id\x82\xd3\xe4\x93\x02+\"!/v1/{parent=workspaces/*}/secrets:\x06secret\x12\x90\x01\n\tGetSecret\x12\'.ai.h2o.securestore.v1.GetSecretRequest\x1a(.ai.h2o.securestore.v1.GetSecretResponse\"0\xda\x41\x04name\x82\xd3\xe4\x93\x02#\x12!/v1/{name=workspaces/*/secrets/*}\x12\x98\x01\n\x0bListSecrets\x12).ai.h2o.securestore.v1.ListSecretsRequest\x1a*.ai.h2o.securestore.v1.ListSecretsResponse\"2\xda\x41\x06parent\x82\xd3\xe4\x93\x02#\x12!/v1/{parent=workspaces/*}/secrets\x12\x99\x01\n\x0c\x44\x65leteSecret\x12*.ai.h2o.securestore.v1.DeleteSecretRequest\x1a+.ai.h2o.securestore.v1.DeleteSecretResponse\"0\xda\x41\x04name\x82\xd3\xe4\x93\x02#*!/v1/{name=workspaces/*/secrets/*}\x12\xa4\x01\n\x0eUndeleteSecret\x12,.ai.h2o.securestore.v1.UndeleteSecretRequest\x1a-.ai.h2o.securestore.v1.UndeleteSecretResponse\"5\x82\xd3\xe4\x93\x02/\"*/v1/{name=workspaces/*/secrets/*}:undelete:\x01*B\xed\x01\n\x19\x63om.ai.h2o.securestore.v1B\x12SecretServiceProtoP\x01ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\xa2\x02\x03\x41HS\xaa\x02\x15\x41i.H2o.Securestore.V1\xca\x02\x15\x41i\\H2o\\Securestore\\V1\xe2\x02!Ai\\H2o\\Securestore\\V1\\GPBMetadata\xea\x02\x18\x41i::H2o::Securestore::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.h2o.securestore.v1.secret_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.ai.h2o.securestore.v1B\022SecretServiceProtoP\001ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\242\002\003AHS\252\002\025Ai.H2o.Securestore.V1\312\002\025Ai\\H2o\\Securestore\\V1\342\002!Ai\\H2o\\Securestore\\V1\\GPBMetadata\352\002\030Ai::H2o::Securestore::V1'
  _globals['_CREATESECRETREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATESECRETREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\033\022\031securestore.h2o.ai/Secret'
  _globals['_CREATESECRETREQUEST'].fields_by_name['secret']._loaded_options = None
  _globals['_CREATESECRETREQUEST'].fields_by_name['secret']._serialized_options = b'\342A\001\002'
  _globals['_CREATESECRETREQUEST'].fields_by_name['secret_id']._loaded_options = None
  _globals['_CREATESECRETREQUEST'].fields_by_name['secret_id']._serialized_options = b'\342A\001\001'
  _globals['_GETSECRETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETSECRETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\033\n\031securestore.h2o.ai/Secret'
  _globals['_LISTSECRETSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTSECRETSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\033\022\031securestore.h2o.ai/Secret'
  _globals['_LISTSECRETSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSECRETSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTSECRETSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSECRETSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTSECRETSREQUEST'].fields_by_name['show_deleted']._loaded_options = None
  _globals['_LISTSECRETSREQUEST'].fields_by_name['show_deleted']._serialized_options = b'\342A\001\001'
  _globals['_DELETESECRETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETESECRETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\033\n\031securestore.h2o.ai/Secret'
  _globals['_UNDELETESECRETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UNDELETESECRETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\033\n\031securestore.h2o.ai/Secret'
  _globals['_SECRETSERVICE'].methods_by_name['CreateSecret']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['CreateSecret']._serialized_options = b'\332A\027parent,secret,secret_id\202\323\344\223\002+\"!/v1/{parent=workspaces/*}/secrets:\006secret'
  _globals['_SECRETSERVICE'].methods_by_name['GetSecret']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['GetSecret']._serialized_options = b'\332A\004name\202\323\344\223\002#\022!/v1/{name=workspaces/*/secrets/*}'
  _globals['_SECRETSERVICE'].methods_by_name['ListSecrets']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['ListSecrets']._serialized_options = b'\332A\006parent\202\323\344\223\002#\022!/v1/{parent=workspaces/*}/secrets'
  _globals['_SECRETSERVICE'].methods_by_name['DeleteSecret']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['DeleteSecret']._serialized_options = b'\332A\004name\202\323\344\223\002#*!/v1/{name=workspaces/*/secrets/*}'
  _globals['_SECRETSERVICE'].methods_by_name['UndeleteSecret']._loaded_options = None
  _globals['_SECRETSERVICE'].methods_by_name['UndeleteSecret']._serialized_options = b'\202\323\344\223\002/\"*/v1/{name=workspaces/*/secrets/*}:undelete:\001*'
  _globals['_CREATESECRETREQUEST']._serialized_start=221
  _globals['_CREATESECRETREQUEST']._serialized_end=398
  _globals['_CREATESECRETRESPONSE']._serialized_start=400
  _globals['_CREATESECRETRESPONSE']._serialized_end=477
  _globals['_GETSECRETREQUEST']._serialized_start=479
  _globals['_GETSECRETREQUEST']._serialized_end=553
  _globals['_GETSECRETRESPONSE']._serialized_start=555
  _globals['_GETSECRETRESPONSE']._serialized_end=629
  _globals['_LISTSECRETSREQUEST']._serialized_start=632
  _globals['_LISTSECRETSREQUEST']._serialized_end=825
  _globals['_LISTSECRETSRESPONSE']._serialized_start=828
  _globals['_LISTSECRETSRESPONSE']._serialized_end=977
  _globals['_DELETESECRETREQUEST']._serialized_start=979
  _globals['_DELETESECRETREQUEST']._serialized_end=1056
  _globals['_DELETESECRETRESPONSE']._serialized_start=1058
  _globals['_DELETESECRETRESPONSE']._serialized_end=1135
  _globals['_UNDELETESECRETREQUEST']._serialized_start=1137
  _globals['_UNDELETESECRETREQUEST']._serialized_end=1216
  _globals['_UNDELETESECRETRESPONSE']._serialized_start=1218
  _globals['_UNDELETESECRETRESPONSE']._serialized_end=1297
  _globals['_SECRETSERVICE']._serialized_start=1300
  _globals['_SECRETSERVICE']._serialized_end=2123
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from h2o_secure_store.gen.ai.h2o.securestore.v1 import oauth_client_service_pb2 as ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2


class OAuthClientServiceStub(object):
    """OAuthClientService manages OAuthClient resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateOAuthClient = channel.unary_unary(
                '/ai.h2o.securestore.v1.OAuthClientService/CreateOAuthClient',
                request_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.CreateOAuthClientRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.CreateOAuthClientResponse.FromString,
                _registered_method=True)
        self.GetOAuthClient = channel.unary_unary(
                '/ai.h2o.securestore.v1.OAuthClientService/GetOAuthClient',
                request_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.GetOAuthClientRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.GetOAuthClientResponse.FromString,
                _registered_method=True)
        self.ListOAuthClients = channel.unary_unary(
                '/ai.h2o.securestore.v1.OAuthClientService/ListOAuthClients',
                request_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.ListOAuthClientsRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.ListOAuthClientsResponse.FromString,
                _registered_method=True)
        self.UpdateOAuthClient = channel.unary_unary(
                '/ai.h2o.securestore.v1.OAuthClientService/UpdateOAuthClient',
                request_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.UpdateOAuthClientRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.UpdateOAuthClientResponse.FromString,
                _registered_method=True)
        self.DeleteOAuthClient = channel.unary_unary(
                '/ai.h2o.securestore.v1.OAuthClientService/DeleteOAuthClient',
                request_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.DeleteOAuthClientRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.DeleteOAuthClientResponse.FromString,
                _registered_method=True)
        self.InvalidateTokenSources = channel.unary_unary(
                '/ai.h2o.securestore.v1.OAuthClientService/InvalidateTokenSources',
                request_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.InvalidateTokenSourcesRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.InvalidateTokenSourcesResponse.FromString,
                _registered_method=True)


class OAuthClientServiceServicer(object):
    """OAuthClientService manages OAuthClient resources.
    """

    def CreateOAuthClient(self, request, context):
        """Creates a new OAuthClient.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOAuthClient(self, request, context):
        """Returns a specific OAuthClient.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOAuthClients(self, request, context):
        """Returns a collection of OAuthClients.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOAuthClient(self, request, context):
        """(-- api-linter: core::0134::method-signature=disabled
        aip.dev/not-precedent: oauth not o_auth --)
        (-- api-linter: core::0134::http-uri-name=disabled
        aip.dev/not-precedent: oauth not o_auth --)
        (-- api-linter: core::0134::http-body=disabled
        aip.dev/not-precedent: oauth not o_auth  --)
        Updates an OAuthClient.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOAuthClient(self, request, context):
        """Deletes an OAuthClient and all child resources like Tokens and TokenSources.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InvalidateTokenSources(self, request, context):
        """Invalidates all child token sources.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OAuthClientServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateOAuthClient': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOAuthClient,
                    request_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.CreateOAuthClientRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.CreateOAuthClientResponse.SerializeToString,
            ),
            'GetOAuthClient': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOAuthClient,
                    request_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.GetOAuthClientRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.GetOAuthClientResponse.SerializeToString,
            ),
            'ListOAuthClients': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOAuthClients,
                    request_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.ListOAuthClientsRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.ListOAuthClientsResponse.SerializeToString,
            ),
            'UpdateOAuthClient': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOAuthClient,
                    request_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.UpdateOAuthClientRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.UpdateOAuthClientResponse.SerializeToString,
            ),
            'DeleteOAuthClient': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOAuthClient,
                    request_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.DeleteOAuthClientRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.DeleteOAuthClientResponse.SerializeToString,
            ),
            'InvalidateTokenSources': grpc.unary_unary_rpc_method_handler(
                    servicer.InvalidateTokenSources,
                    request_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.InvalidateTokenSourcesRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.InvalidateTokenSourcesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ai.h2o.securestore.v1.OAuthClientService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class OAuthClientService(object):
    """OAuthClientService manages OAuthClient resources.
    """

    @staticmethod
    def CreateOAuthClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.h2o.securestore.v1.OAuthClientService/CreateOAuthClient',
            ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.CreateOAuthClientRequest.SerializeToString,
            ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.CreateOAuthClientResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetOAuthClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.h2o.securestore.v1.OAuthClientService/GetOAuthClient',
            ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.GetOAuthClientRequest.SerializeToString,
            ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.GetOAuthClientResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListOAuthClients(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.h2o.securestore.v1.OAuthClientService/ListOAuthClients',
            ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.ListOAuthClientsRequest.SerializeToString,
            ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.ListOAuthClientsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateOAuthClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.h2o.securestore.v1.OAuthClientService/UpdateOAuthClient',
            ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.UpdateOAuthClientRequest.SerializeToString,
            ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.UpdateOAuthClientResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteOAuthClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.h2o.securestore.v1.OAuthClientService/DeleteOAuthClient',
            ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.DeleteOAuthClientRequest.SerializeToString,
            ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.DeleteOAuthClientResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def InvalidateTokenSources(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.h2o.securestore.v1.OAuthClientService/InvalidateTokenSources',
            ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.InvalidateTokenSourcesRequest.SerializeToString,
            ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__service__pb2.InvalidateTokenSourcesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



import base64
from typing import List
from typing import Optional

from h2o_secure_store.clients.auth.token_api_client import TokenApiClient
from h2o_secure_store.clients.connection_config import ConnectionConfig
from h2o_secure_store.clients.secret_version.page import SecretVersionsPage
from h2o_secure_store.clients.secret_version.secret_version import SecretVersion
from h2o_secure_store.clients.secret_version.secret_version import from_api_object
from h2o_secure_store.exception import CustomApiException
from h2o_secure_store.gen import ApiException
from h2o_secure_store.gen import Configuration
from h2o_secure_store.gen.api.secret_version_service_api import SecretVersionServiceApi
from h2o_secure_store.gen.model.v1_list_secret_versions_response import (
    V1ListSecretVersionsResponse,
)
from h2o_secure_store.gen.model.v1_secret_version import V1SecretVersion


class SecretVersionClient:
    """SecretVersionClient manages SecretVersions."""

    def __init__(
            self,
            connection_config: ConnectionConfig,
            verify_ssl: bool = True,
            ssl_ca_cert: Optional[str] = None,
    ):
        configuration = Configuration(host=connection_config.server_url)
        configuration.verify_ssl = verify_ssl
        configuration.ssl_ca_cert = ssl_ca_cert

        with TokenApiClient(
                configuration, connection_config.token_provider
        ) as api_client:
            self.api_instance = SecretVersionServiceApi(api_client)

    def create_secret_version(
            self,
            parent: str,
            secret_version: SecretVersion,
    ) -> SecretVersion:
        """Creates a SecretVersion.

        Args:
            parent (str): The resource name of the secret to associate with the SecretVersion.
                Format is `workspaces/*/secrets/*`.
            secret_version (SecretVersion): SecretVersion object to create.

        Returns:
            SecretVersion: SecretVersion object.
        """
        created_api_object: V1SecretVersion

        try:
            created_api_object = self.api_instance.secret_version_service_create_secret_version(
                parent=parent,
                secret_version=secret_version.to_api_object(),
            ).secret_version
        except ApiException as e:
            raise CustomApiException(e)
        return from_api_object(api_object=created_api_object)

    def get_secret_version(self, name: str) -> SecretVersion:
        """Returns a SecretVersion.

        Args:
            name (str): The resource name of the SecretVersion. Format is `workspaces/*/secrets/*/secret_versions/*`.

        Returns:
            SecretVersion: SecretVersion object.
        """
        api_object: V1SecretVersion

        try:
            api_object = self.api_instance.secret_version_service_get_secret_version(
                name_2=name
            ).secret_version
        except ApiException as e:
            raise CustomApiException(e)

        return from_api_object(api_object=api_object)

    def list_secret_versions(
            self,
            parent: str,
            page_size: int = 0,
            page_token: str = "",
            show_deleted: bool = False,
    ) -> SecretVersionsPage:
        """Lists SecretVersions.

        Args:
            parent (str): The resource name of the secret from which to list SecretVersions.
                Format is `workspaces/*/secrets/*`.
            page_size (int): Maximum number of SecretVersions to return in a response.
                If unspecified (or set to 0), at most 50 SecretVersions will be returned.
                The maximum value is 1000; values above 1000 will be coerced to 1000.
            page_token (str): Page token.
                Leave unset to receive the initial page.
                To list any subsequent pages use the value of 'next_page_token' returned from the SecretVersionsPage.
            show_deleted (bool): If set to true, include deleted SecretVersions in the response.

        Returns:
            SecretVersionsPage: SecretVersionsPage object.
        """
        list_response: V1ListSecretVersionsResponse

        try:
            list_response = (
                self.api_instance.secret_version_service_list_secret_versions(
                    parent=parent,
                    page_size=page_size,
                    page_token=page_token,
                )
            )
        except ApiException as e:
            raise CustomApiException(e)

        return SecretVersionsPage(list_response)

    def list_all_secret_versions(self, parent: str) -> List[SecretVersion]:
        """ List all SecretVersions.

        Args:
            parent (str): The resource name of the secret from which to list SecretVersions.
                Format is `workspaces/*/secrets/*`.

        Returns:
            List of SecretVersion.
        """
        all_secret_versions: List[SecretVersion] = []
        next_page_token = ""
        while True:
            secret_version_list = self.list_secret_versions(
                parent=parent,
                page_size=0,
                page_token=next_page_token,
            )
            all_secret_versions = all_secret_versions + secret_version_list.secret_versions
            next_page_token = secret_version_list.next_page_token
            if next_page_token == "":
                break

        return all_secret_versions

    def reveal_secret_version_value(self, name: str) -> bytes:
        """Reveals a SecretVersion value.

        Args:
            name (str): The resource name of the SecretVersion. Format is `workspaces/*/secrets/*/secretVersions/*`.
        """
        try:
            value = self.api_instance.secret_version_service_reveal_secret_version_value(
                name=name
            ).value
        except ApiException as e:
            raise CustomApiException(e)

        return base64.b64decode(value)



from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.api import resource_pb2 as _resource_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OAuthClient(_message.Message):
    __slots__ = ("name", "display_name", "issuer", "client_id", "client_secret", "client_secret_set", "authorization_endpoint", "token_endpoint", "extra_scopes", "refresh_disabled", "login_principal_claim", "callback_uri", "creator", "updater", "create_time", "update_time", "uid")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    ISSUER_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_SECRET_FIELD_NUMBER: _ClassVar[int]
    CLIENT_SECRET_SET_FIELD_NUMBER: _ClassVar[int]
    AUTHORIZATION_ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    TOKEN_ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    EXTRA_SCOPES_FIELD_NUMBER: _ClassVar[int]
    REFRESH_DISABLED_FIELD_NUMBER: _ClassVar[int]
    LOGIN_PRINCIPAL_CLAIM_FIELD_NUMBER: _ClassVar[int]
    CALLBACK_URI_FIELD_NUMBER: _ClassVar[int]
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    UPDATER_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    UID_FIELD_NUMBER: _ClassVar[int]
    name: str
    display_name: str
    issuer: str
    client_id: str
    client_secret: str
    client_secret_set: bool
    authorization_endpoint: str
    token_endpoint: str
    extra_scopes: _containers.RepeatedScalarFieldContainer[str]
    refresh_disabled: bool
    login_principal_claim: str
    callback_uri: str
    creator: str
    updater: str
    create_time: _timestamp_pb2.Timestamp
    update_time: _timestamp_pb2.Timestamp
    uid: str
    def __init__(self, name: _Optional[str] = ..., display_name: _Optional[str] = ..., issuer: _Optional[str] = ..., client_id: _Optional[str] = ..., client_secret: _Optional[str] = ..., client_secret_set: bool = ..., authorization_endpoint: _Optional[str] = ..., token_endpoint: _Optional[str] = ..., extra_scopes: _Optional[_Iterable[str]] = ..., refresh_disabled: bool = ..., login_principal_claim: _Optional[str] = ..., callback_uri: _Optional[str] = ..., creator: _Optional[str] = ..., updater: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., uid: _Optional[str] = ...) -> None: ...



from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.api import resource_pb2 as _resource_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SecretVersion(_message.Message):
    __slots__ = ("name", "value", "creator", "create_time", "uid")
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    UID_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: bytes
    creator: str
    create_time: _timestamp_pb2.Timestamp
    uid: str
    def __init__(self, name: _Optional[str] = ..., value: _Optional[bytes] = ..., creator: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., uid: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from h2o_secure_store.gen.ai.h2o.securestore.v1 import token_source_service_pb2 as ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2


class TokenSourceServiceStub(object):
    """TokenSourceService manages TokenSource resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateTokenSource = channel.unary_unary(
                '/ai.h2o.securestore.v1.TokenSourceService/CreateTokenSource',
                request_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.CreateTokenSourceRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.CreateTokenSourceResponse.FromString,
                _registered_method=True)
        self.GetTokenSource = channel.unary_unary(
                '/ai.h2o.securestore.v1.TokenSourceService/GetTokenSource',
                request_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.GetTokenSourceRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.GetTokenSourceResponse.FromString,
                _registered_method=True)
        self.ListTokenSources = channel.unary_unary(
                '/ai.h2o.securestore.v1.TokenSourceService/ListTokenSources',
                request_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.ListTokenSourcesRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.ListTokenSourcesResponse.FromString,
                _registered_method=True)
        self.DeleteTokenSource = channel.unary_unary(
                '/ai.h2o.securestore.v1.TokenSourceService/DeleteTokenSource',
                request_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.DeleteTokenSourceRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.DeleteTokenSourceResponse.FromString,
                _registered_method=True)


class TokenSourceServiceServicer(object):
    """TokenSourceService manages TokenSource resources.
    """

    def CreateTokenSource(self, request, context):
        """Creates a new TokenSource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTokenSource(self, request, context):
        """Returns a specific TokenSource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTokenSources(self, request, context):
        """Returns a collection of TokenSources.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteTokenSource(self, request, context):
        """Deletes a TokenSource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TokenSourceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateTokenSource': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTokenSource,
                    request_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.CreateTokenSourceRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.CreateTokenSourceResponse.SerializeToString,
            ),
            'GetTokenSource': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTokenSource,
                    request_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.GetTokenSourceRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.GetTokenSourceResponse.SerializeToString,
            ),
            'ListTokenSources': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTokenSources,
                    request_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.ListTokenSourcesRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.ListTokenSourcesResponse.SerializeToString,
            ),
            'DeleteTokenSource': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteTokenSource,
                    request_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.DeleteTokenSourceRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.DeleteTokenSourceResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ai.h2o.securestore.v1.TokenSourceService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TokenSourceService(object):
    """TokenSourceService manages TokenSource resources.
    """

    @staticmethod
    def CreateTokenSource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.h2o.securestore.v1.TokenSourceService/CreateTokenSource',
            ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.CreateTokenSourceRequest.SerializeToString,
            ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.CreateTokenSourceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTokenSource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.h2o.securestore.v1.TokenSourceService/GetTokenSource',
            ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.GetTokenSourceRequest.SerializeToString,
            ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.GetTokenSourceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListTokenSources(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.h2o.securestore.v1.TokenSourceService/ListTokenSources',
            ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.ListTokenSourcesRequest.SerializeToString,
            ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.ListTokenSourcesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteTokenSource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.h2o.securestore.v1.TokenSourceService/DeleteTokenSource',
            ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.DeleteTokenSourceRequest.SerializeToString,
            ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__service__pb2.DeleteTokenSourceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



import os

import h2o_authn

import h2o_secure_store


def test_login_custom_with_token_provider():
    tp = h2o_authn.TokenProvider(
        issuer_url=os.getenv("PLATFORM_OIDC_URL"),
        refresh_token=os.getenv("PLATFORM_TOKEN_SUPER_ADMIN"),
        client_id=os.getenv("PLATFORM_OIDC_CLIENT_ID"),
    )
    h2o_secure_store.login_custom_with_token_provider(
        endpoint=os.getenv("SECURE_STORE_SERVER_URL"),
        token_provider=tp,
    )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/securestore/v1/oauth_client_service.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from h2o_secure_store.gen.ai.h2o.securestore.v1 import oauth_client_pb2 as ai_dot_h2o_dot_securestore_dot_v1_dot_oauth__client__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0ai/h2o/securestore/v1/oauth_client_service.proto\x12\x15\x61i.h2o.securestore.v1\x1a(ai/h2o/securestore/v1/oauth_client.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/api/resource.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\"\x95\x01\n\x18\x43reateOAuthClientRequest\x12K\n\x0coauth_client\x18\x01 \x01(\x0b\x32\".ai.h2o.securestore.v1.OAuthClientB\x04\xe2\x41\x01\x02R\x0boauthClient\x12,\n\x0foauth_client_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\roauthClientId\"b\n\x19\x43reateOAuthClientResponse\x12\x45\n\x0coauth_client\x18\x01 \x01(\x0b\x32\".ai.h2o.securestore.v1.OAuthClientR\x0boauthClient\"T\n\x15GetOAuthClientRequest\x12;\n\x04name\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \n\x1esecurestore.h2o.ai/OAuthClientR\x04name\"_\n\x16GetOAuthClientResponse\x12\x45\n\x0coauth_client\x18\x01 \x01(\x0b\x32\".ai.h2o.securestore.v1.OAuthClientR\x0boauthClient\"a\n\x17ListOAuthClientsRequest\x12!\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x8b\x01\n\x18ListOAuthClientsResponse\x12G\n\roauth_clients\x18\x01 \x03(\x0b\x32\".ai.h2o.securestore.v1.OAuthClientR\x0coauthClients\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\xaa\x01\n\x18UpdateOAuthClientRequest\x12K\n\x0coauth_client\x18\x01 \x01(\x0b\x32\".ai.h2o.securestore.v1.OAuthClientB\x04\xe2\x41\x01\x02R\x0boauthClient\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x02R\nupdateMask\"b\n\x19UpdateOAuthClientResponse\x12\x45\n\x0coauth_client\x18\x01 \x01(\x0b\x32\".ai.h2o.securestore.v1.OAuthClientR\x0boauthClient\"W\n\x18\x44\x65leteOAuthClientRequest\x12;\n\x04name\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \n\x1esecurestore.h2o.ai/OAuthClientR\x04name\"\x1b\n\x19\x44\x65leteOAuthClientResponse\"\\\n\x1dInvalidateTokenSourcesRequest\x12;\n\x04name\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \n\x1esecurestore.h2o.ai/OAuthClientR\x04name\" \n\x1eInvalidateTokenSourcesResponse2\xb8\x08\n\x12OAuthClientService\x12\xbd\x01\n\x11\x43reateOAuthClient\x12/.ai.h2o.securestore.v1.CreateOAuthClientRequest\x1a\x30.ai.h2o.securestore.v1.CreateOAuthClientResponse\"E\xda\x41\x1coauth_client,oauth_client_id\x82\xd3\xe4\x93\x02 \"\x10/v1/oauthClients:\x0coauth_client\x12\x97\x01\n\x0eGetOAuthClient\x12,.ai.h2o.securestore.v1.GetOAuthClientRequest\x1a-.ai.h2o.securestore.v1.GetOAuthClientResponse\"(\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/{name=oauthClients/*}\x12\x8d\x01\n\x10ListOAuthClients\x12..ai.h2o.securestore.v1.ListOAuthClientsRequest\x1a/.ai.h2o.securestore.v1.ListOAuthClientsResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/oauthClients\x12\xcf\x01\n\x11UpdateOAuthClient\x12/.ai.h2o.securestore.v1.UpdateOAuthClientRequest\x1a\x30.ai.h2o.securestore.v1.UpdateOAuthClientResponse\"W\xda\x41\x18oauth_client,update_mask\x82\xd3\xe4\x93\x02\x36\x32&/v1/{oauth_client.name=oauthClients/*}:\x0coauth_client\x12\xa0\x01\n\x11\x44\x65leteOAuthClient\x12/.ai.h2o.securestore.v1.DeleteOAuthClientRequest\x1a\x30.ai.h2o.securestore.v1.DeleteOAuthClientResponse\"(\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1b*\x19/v1/{name=oauthClients/*}\x12\xc2\x01\n\x16InvalidateTokenSources\x12\x34.ai.h2o.securestore.v1.InvalidateTokenSourcesRequest\x1a\x35.ai.h2o.securestore.v1.InvalidateTokenSourcesResponse\";\x82\xd3\xe4\x93\x02\x35\"0/v1/{name=oauthClients/*}:invalidateTokenSources:\x01*B\xf2\x01\n\x19\x63om.ai.h2o.securestore.v1B\x17OauthClientServiceProtoP\x01ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\xa2\x02\x03\x41HS\xaa\x02\x15\x41i.H2o.Securestore.V1\xca\x02\x15\x41i\\H2o\\Securestore\\V1\xe2\x02!Ai\\H2o\\Securestore\\V1\\GPBMetadata\xea\x02\x18\x41i::H2o::Securestore::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.h2o.securestore.v1.oauth_client_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.ai.h2o.securestore.v1B\027OauthClientServiceProtoP\001ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\242\002\003AHS\252\002\025Ai.H2o.Securestore.V1\312\002\025Ai\\H2o\\Securestore\\V1\342\002!Ai\\H2o\\Securestore\\V1\\GPBMetadata\352\002\030Ai::H2o::Securestore::V1'
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['oauth_client']._loaded_options = None
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['oauth_client']._serialized_options = b'\342A\001\002'
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['oauth_client_id']._loaded_options = None
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['oauth_client_id']._serialized_options = b'\342A\001\001'
  _globals['_GETOAUTHCLIENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETOAUTHCLIENTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A \n\036securestore.h2o.ai/OAuthClient'
  _globals['_LISTOAUTHCLIENTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTOAUTHCLIENTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTOAUTHCLIENTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTOAUTHCLIENTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['oauth_client']._loaded_options = None
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['oauth_client']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\002'
  _globals['_DELETEOAUTHCLIENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEOAUTHCLIENTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A \n\036securestore.h2o.ai/OAuthClient'
  _globals['_INVALIDATETOKENSOURCESREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_INVALIDATETOKENSOURCESREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A \n\036securestore.h2o.ai/OAuthClient'
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['CreateOAuthClient']._loaded_options = None
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['CreateOAuthClient']._serialized_options = b'\332A\034oauth_client,oauth_client_id\202\323\344\223\002 \"\020/v1/oauthClients:\014oauth_client'
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['GetOAuthClient']._loaded_options = None
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['GetOAuthClient']._serialized_options = b'\332A\004name\202\323\344\223\002\033\022\031/v1/{name=oauthClients/*}'
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['ListOAuthClients']._loaded_options = None
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['ListOAuthClients']._serialized_options = b'\202\323\344\223\002\022\022\020/v1/oauthClients'
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['UpdateOAuthClient']._loaded_options = None
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['UpdateOAuthClient']._serialized_options = b'\332A\030oauth_client,update_mask\202\323\344\223\00262&/v1/{oauth_client.name=oauthClients/*}:\014oauth_client'
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['DeleteOAuthClient']._loaded_options = None
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['DeleteOAuthClient']._serialized_options = b'\332A\004name\202\323\344\223\002\033*\031/v1/{name=oauthClients/*}'
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['InvalidateTokenSources']._loaded_options = None
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['InvalidateTokenSources']._serialized_options = b'\202\323\344\223\0025\"0/v1/{name=oauthClients/*}:invalidateTokenSources:\001*'
  _globals['_CREATEOAUTHCLIENTREQUEST']._serialized_start=267
  _globals['_CREATEOAUTHCLIENTREQUEST']._serialized_end=416
  _globals['_CREATEOAUTHCLIENTRESPONSE']._serialized_start=418
  _globals['_CREATEOAUTHCLIENTRESPONSE']._serialized_end=516
  _globals['_GETOAUTHCLIENTREQUEST']._serialized_start=518
  _globals['_GETOAUTHCLIENTREQUEST']._serialized_end=602
  _globals['_GETOAUTHCLIENTRESPONSE']._serialized_start=604
  _globals['_GETOAUTHCLIENTRESPONSE']._serialized_end=699
  _globals['_LISTOAUTHCLIENTSREQUEST']._serialized_start=701
  _globals['_LISTOAUTHCLIENTSREQUEST']._serialized_end=798
  _globals['_LISTOAUTHCLIENTSRESPONSE']._serialized_start=801
  _globals['_LISTOAUTHCLIENTSRESPONSE']._serialized_end=940
  _globals['_UPDATEOAUTHCLIENTREQUEST']._serialized_start=943
  _globals['_UPDATEOAUTHCLIENTREQUEST']._serialized_end=1113
  _globals['_UPDATEOAUTHCLIENTRESPONSE']._serialized_start=1115
  _globals['_UPDATEOAUTHCLIENTRESPONSE']._serialized_end=1213
  _globals['_DELETEOAUTHCLIENTREQUEST']._serialized_start=1215
  _globals['_DELETEOAUTHCLIENTREQUEST']._serialized_end=1302
  _globals['_DELETEOAUTHCLIENTRESPONSE']._serialized_start=1304
  _globals['_DELETEOAUTHCLIENTRESPONSE']._serialized_end=1331
  _globals['_INVALIDATETOKENSOURCESREQUEST']._serialized_start=1333
  _globals['_INVALIDATETOKENSOURCESREQUEST']._serialized_end=1425
  _globals['_INVALIDATETOKENSOURCESRESPONSE']._serialized_start=1427
  _globals['_INVALIDATETOKENSOURCESRESPONSE']._serialized_end=1459
  _globals['_OAUTHCLIENTSERVICE']._serialized_start=1462
  _globals['_OAUTHCLIENTSERVICE']._serialized_end=2542
# @@protoc_insertion_point(module_scope)



import http

import pytest

from h2o_secure_store.clients.oauth_client.oauth_client import OAuthClient
from h2o_secure_store.clients.token_source.client import TokenSourceClient
from h2o_secure_store.exception import CustomApiException


def test_create_token_source(
    delete_all_token_sources_before_after,
    oauth_client1: OAuthClient,
    user_token_source_client: TokenSourceClient,
):
    token_source = user_token_source_client.create_token_source(
        oauth_client_id=oauth_client1.oauth_client_id,
        redirect_uri="http://localhost:8080",
        token_source_id="token-source1",
    )

    assert token_source.token_source_id == "token-source1"
    assert token_source.oauth_client_id == "oauth-client1"
    assert token_source.name == "oauthClients/oauth-client1/tokenSources/token-source1"
    assert token_source.creator != ""
    assert token_source.create_time is not None
    assert token_source.login_time is None
    assert token_source.login_required is True
    assert token_source.login_uri is not None
    assert token_source.redirect_uri is not None
    assert token_source.uid != ""


def test_create_token_source_already_exists(
    delete_all_token_sources_before_after,
    oauth_client1: OAuthClient,
    user_token_source_client: TokenSourceClient,
):
    user_token_source_client.create_token_source(
        oauth_client_id=oauth_client1.oauth_client_id,
        redirect_uri="http://localhost:8080",
        token_source_id="token-source-2",
    )

    with pytest.raises(CustomApiException) as exc:
        user_token_source_client.create_token_source(
            oauth_client_id=oauth_client1.oauth_client_id,
            redirect_uri="http://localhost:8080",
            token_source_id="token-source-2",
        )

    # grpc AlreadyExists == http Conflict 409
    assert exc.value.status == http.HTTPStatus.CONFLICT


def test_create_token_source_autogenerated_id(
    delete_all_token_sources_before_after,
    oauth_client1: OAuthClient,
    user_token_source_client: TokenSourceClient,
):
    token_source = user_token_source_client.create_token_source(
        oauth_client_id=oauth_client1.oauth_client_id,
        redirect_uri="http://localhost:8080",
        token_source_id="token-source-3",
    )
    assert token_source.token_source_id != ""




import datetime
import http
import time

import pytest

from h2o_secure_store.clients.base.workspace import DEFAULT_WORKSPACE
from h2o_secure_store.clients.secret.client import SecretClient
from h2o_secure_store.clients.secret_version.client import SecretVersionClient
from h2o_secure_store.clients.secret_version.secret_version import SecretVersion
from h2o_secure_store.exception import CustomApiException


def test_prune_deleted_secret(
        delete_secret_rows_before,
        user_secret_client: SecretClient,
        user_secret_version_client: SecretVersionClient,
):
    s = user_secret_client.create_secret(
        parent=DEFAULT_WORKSPACE,
        secret_id="secret1",
    )

    v = user_secret_version_client.create_secret_version(
        parent=s.name,
        secret_version=SecretVersion(
            value=b"secret1",
        ),
    )

    deleted = user_secret_client.delete_secret(name=s.name)
    now_utc = datetime.datetime.now(tz=datetime.timezone.utc)

    assert deleted.purge_time.astimezone(datetime.timezone.utc) > now_utc
    assert deleted.purge_time.astimezone(datetime.timezone.utc) < now_utc + datetime.timedelta(seconds=5)

    # Wait for the secret to be pruned, reconciliation every 2s + 2s for the prune duration
    time.sleep(5)

    with pytest.raises(CustomApiException) as exc:
        user_secret_client.get_secret(name=deleted.name)
    assert exc.value.status == http.HTTPStatus.NOT_FOUND

    with pytest.raises(CustomApiException) as exc:
        user_secret_version_client.get_secret_version(name=v.name)
    assert exc.value.status == http.HTTPStatus.NOT_FOUND




from google.api import resource_pb2 as _resource_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TokenSource(_message.Message):
    __slots__ = ("name", "redirect_uri", "login_uri", "login_required", "access_token", "issue_time", "expire_time", "subject", "login_principal", "creator", "create_time", "login_time", "uid")
    NAME_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URI_FIELD_NUMBER: _ClassVar[int]
    LOGIN_URI_FIELD_NUMBER: _ClassVar[int]
    LOGIN_REQUIRED_FIELD_NUMBER: _ClassVar[int]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    ISSUE_TIME_FIELD_NUMBER: _ClassVar[int]
    EXPIRE_TIME_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    LOGIN_PRINCIPAL_FIELD_NUMBER: _ClassVar[int]
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    LOGIN_TIME_FIELD_NUMBER: _ClassVar[int]
    UID_FIELD_NUMBER: _ClassVar[int]
    name: str
    redirect_uri: str
    login_uri: str
    login_required: bool
    access_token: str
    issue_time: _timestamp_pb2.Timestamp
    expire_time: _timestamp_pb2.Timestamp
    subject: str
    login_principal: str
    creator: str
    create_time: _timestamp_pb2.Timestamp
    login_time: _timestamp_pb2.Timestamp
    uid: str
    def __init__(self, name: _Optional[str] = ..., redirect_uri: _Optional[str] = ..., login_uri: _Optional[str] = ..., login_required: bool = ..., access_token: _Optional[str] = ..., issue_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., expire_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., subject: _Optional[str] = ..., login_principal: _Optional[str] = ..., creator: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., login_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., uid: _Optional[str] = ...) -> None: ...



from h2o_secure_store.clients.login import login  # noqa
from h2o_secure_store.clients.login import login_custom  # noqa
from h2o_secure_store.clients.login import login_custom_with_token_provider  # noqa


import pprint

from h2o_secure_store.clients.oauth_client.oauth_client import from_api_object
from h2o_secure_store.gen.model.v1_list_o_auth_clients_response import (
    V1ListOAuthClientsResponse,
)


class OAuthClientsPage:
    """Class represents a list of OAuthClients together with a next_page_token for listing all OAuthClients."""

    def __init__(self, list_api_response: V1ListOAuthClientsResponse) -> None:
        api_objects = list_api_response.oauth_clients
        self.oauth_clients = []
        for api_oauth_client in api_objects:
            self.oauth_clients.append(from_api_object(api_oauth_client))

        self.next_page_token = list_api_response.next_page_token

    def __repr__(self) -> str:
        return pprint.pformat(self.__dict__)



import http

import pytest

from h2o_secure_store.clients.base.workspace import DEFAULT_WORKSPACE
from h2o_secure_store.clients.secret.client import SecretClient
from h2o_secure_store.clients.secret.state import SecretState
from h2o_secure_store.exception import CustomApiException


def test_create_secret(
        delete_secret_rows_before,
        user_secret_client: SecretClient,
):
    secret = user_secret_client.create_secret(
        parent=DEFAULT_WORKSPACE,
        secret_id="secret1",
        display_name="Test Secret",
        annotations={"key1": "value1", "key2": "value2"},
    )

    assert secret.name == f"workspaces/{secret.get_workspace_id()}/secrets/secret1"
    assert secret.display_name == "Test Secret"
    assert secret.annotations == {"key1": "value1", "key2": "value2"}
    assert secret.state == SecretState.STATE_ACTIVE
    assert secret.creator != ""
    assert secret.create_time is not None
    assert secret.delete_time is None
    assert secret.purge_time is None
    assert secret.deleter == ""
    assert secret.uid != ""


def test_create_secret_generate_secret_id(
        delete_secret_rows_before,
        user_secret_client: SecretClient,
):
    s1 = user_secret_client.create_secret(
        parent=DEFAULT_WORKSPACE,
    )

    s2 = user_secret_client.create_secret(
        parent=DEFAULT_WORKSPACE,
    )

    assert s1.name != s2.name
    assert s1.get_secret_id() != s2.get_secret_id()


def test_create_secret_already_exists(
        delete_secret_rows_before,
        user_secret_client: SecretClient,
):
    secret = user_secret_client.create_secret(
        parent=DEFAULT_WORKSPACE,
        secret_id="secret1",
    )

    with pytest.raises(CustomApiException) as exc:
        # Try to create Kernel with the same ID.
        user_secret_client.create_secret(
            parent=DEFAULT_WORKSPACE,
            secret_id=secret.get_secret_id(),
        )

    # grpc AlreadyExists == http Conflict 409
    assert exc.value.status == http.HTTPStatus.CONFLICT


def test_create_secret_workspace_not_found(
        user_secret_client: SecretClient,
):
    with pytest.raises(CustomApiException) as exc:
        user_secret_client.create_secret(
            parent="workspaces/non-existing",
            secret_id="secret1",
        )

    assert exc.value.status == http.HTTPStatus.FORBIDDEN


def test_create_secret_workspace_forbidden(
        delete_secret_rows_before,
        user_secret_client: SecretClient,
        super_admin_secret_client: SecretClient,
):
    s1 = user_secret_client.create_secret(
        parent=DEFAULT_WORKSPACE,
    )

    with pytest.raises(CustomApiException) as exc:
        super_admin_secret_client.create_secret(
            parent=f"workspaces/{s1.get_workspace_id()}",
            secret_id="secret2",
        )

    assert exc.value.status == http.HTTPStatus.FORBIDDEN




from typing import Callable

from h2o_secure_store.gen.api_client import ApiClient
from h2o_secure_store.gen.api_client import Configuration


class TokenApiClient(ApiClient):
    """Overrides update_params_for_auth method of the generated ApiClient classes"""

    def __init__(self, configuration: Configuration, token_provider: Callable[[], str]):
        self._token_provider = token_provider
        super().__init__(configuration=configuration)

    def update_params_for_auth(
        self,
        headers,
        queries,
        auth_settings,
        resource_path,
        method,
        body,
        request_auths=None,
    ):
        token = self._token_provider()
        headers["Authorization"] = f"Bearer {token}"



import base64
import pprint
from datetime import datetime
from typing import Optional

from h2o_secure_store.gen.model.v1_secret_version import V1SecretVersion


class SecretVersion:
    def __init__(
            self,
            value: bytes,
            name: str = "",
            creator: str = "",
            uid: str = "",
            create_time: Optional[datetime] = None,
    ):
        """
        Args:
            value (bytes, optional): Required. Input only. The secret payload of the SecretVersion.
                                     Must be no larger than 64KiB.
                                     Can be retrieved using the reveal_secret_version_value method.
            name (str, optional): Resource name of the SecretVersion. Format is `workspaces/*/secret_versions/*`.
            creator (str, optional): Name of an entity that created the SecretVersion.
            uid (str, optional): Globally unique identifier of the resource.
            create_time (str, datetime): Time when the SecretVersion was created.
        """

        self.name = name
        self.value = value
        self.creator = creator
        self.uid = uid
        self.create_time = create_time

    def get_secret_version_id(self) -> str:
        segments = self.name.split("/")
        if len(segments) != 6:
            return ""

        return segments[5]

    def __repr__(self) -> str:
        return pprint.pformat(self.__dict__)

    def to_api_object(self) -> V1SecretVersion:
        return V1SecretVersion(
            value=base64.b64encode(self.value).decode('utf-8'),
        )


def from_api_object(api_object: V1SecretVersion) -> SecretVersion:
    return SecretVersion(
        name=api_object.name,
        value=base64.b64decode(api_object.value),
        creator=api_object.creator,
        create_time=api_object.create_time,
        uid=api_object.uid,
    )



import http

import pytest

from h2o_secure_store.clients.oauth_client.oauth_client import OAuthClient
from h2o_secure_store.clients.token_source.client import TokenSourceClient
from h2o_secure_store.exception import CustomApiException


@pytest.mark.parametrize(
    ["page_size", "page_token"],
    [
        (-20, ""),
        (0, "non-existing-token"),
    ],
)
def test_list_token_sources_validation(
        oauth_client1: OAuthClient,
        user_token_source_client: TokenSourceClient,
        page_size,
        page_token
):
    with pytest.raises(CustomApiException) as exc:
        user_token_source_client.list_token_sources(
            oauth_client_id=oauth_client1.oauth_client_id,
            page_size=page_size,
            page_token=page_token,
        )
    assert exc.value.status == http.HTTPStatus.BAD_REQUEST


def test_list_token_sources_pagination(
        delete_all_token_sources_before_after,
        user_token_source_client: TokenSourceClient,
        token_source1,
        token_source2,
        token_source3,
):
    # Test getting first page.
    page = user_token_source_client.list_token_sources(oauth_client_id=token_source1.oauth_client_id, page_size=1)
    assert len(page.token_sources) == 1
    assert page.next_page_token != ""

    # Test getting second page.
    page = user_token_source_client.list_token_sources(
        oauth_client_id=token_source1.oauth_client_id,
        page_size=1,
        page_token=page.next_page_token,
    )
    assert len(page.token_sources) == 1
    assert page.next_page_token != ""

    # Test getting last page.
    # Test getting second page.
    page = user_token_source_client.list_token_sources(
        oauth_client_id=token_source1.oauth_client_id,
        page_size=1,
        page_token=page.next_page_token,
    )
    assert len(page.token_sources) == 1
    assert page.next_page_token == ""

    # Test exceeding max page size.
    page = user_token_source_client.list_token_sources(oauth_client_id=token_source1.oauth_client_id, page_size=5000)
    assert len(page.token_sources) == 3
    assert page.next_page_token == ""


def test_list_all_token_sources(
        delete_all_token_sources_before_after,
        user_token_source_client: TokenSourceClient,
        token_source1,
        token_source2,
        token_source3,
):
    token_sources = user_token_source_client.list_all_token_sources(oauth_client_id=token_source1.oauth_client_id)
    assert len(token_sources) == 3
    assert token_sources[0].token_source_id == token_source3.token_source_id
    assert token_sources[1].token_source_id == token_source2.token_source_id
    assert token_sources[2].token_source_id == token_source1.token_source_id


def test_list_token_sources_not_owned(
        delete_all_token_sources_before_after,
        super_admin_token_source_client: TokenSourceClient,
        token_source1,
):
    # token_source1 is created with user_token_source_client - different user
    token_sources = super_admin_token_source_client.list_all_token_sources(oauth_client_id=token_source1.oauth_client_id)
    assert len(token_sources) == 0



import pprint

from h2o_secure_store.clients.secret_version.secret_version import from_api_object
from h2o_secure_store.gen.model.v1_list_secret_versions_response import (
    V1ListSecretVersionsResponse,
)


class SecretVersionsPage:
    """Class represents a list of SecretVersions together with a next_page_token for listing all SecretVersions."""

    def __init__(self, list_api_response: V1ListSecretVersionsResponse) -> None:
        api_objects = list_api_response.secret_versions
        self.secret_versions = []
        for api_secret_version in api_objects:
            self.secret_versions.append(from_api_object(api_secret_version))

        self.next_page_token = list_api_response.next_page_token

    def __repr__(self) -> str:
        return pprint.pformat(self.__dict__)



import http

import pytest

from h2o_secure_store.clients.base.workspace import DEFAULT_WORKSPACE
from h2o_secure_store.clients.secret.client import SecretClient
from h2o_secure_store.clients.secret.state import SecretState
from h2o_secure_store.exception import CustomApiException


def test_undelete_secret(
        delete_secret_rows_before,
        user_secret_client: SecretClient,
):
    s = user_secret_client.create_secret(
        parent=DEFAULT_WORKSPACE,
        secret_id="secret1",
    )

    user_secret_client.delete_secret(name=s.name)

    undeleted = user_secret_client.undelete_secret(name=s.name)

    assert undeleted.name == f"workspaces/{s.get_workspace_id()}/secrets/secret1"
    assert undeleted.state == SecretState.STATE_ACTIVE
    assert undeleted.creator != ""
    assert undeleted.create_time is not None
    assert undeleted.delete_time is None
    assert undeleted.purge_time is None
    assert undeleted.deleter == ""


def test_undelete_undeleted_secret(
        delete_secret_rows_before,
        user_secret_client: SecretClient,
):
    s = user_secret_client.create_secret(
        parent=DEFAULT_WORKSPACE,
        secret_id="secret1",
    )

    with pytest.raises(CustomApiException) as exc:
        user_secret_client.undelete_secret(name=s.name)
    assert exc.value.status == http.HTTPStatus.BAD_REQUEST


def test_undelete_secret_not_found(
        user_secret_client: SecretClient,
):
    with pytest.raises(CustomApiException) as exc:
        user_secret_client.undelete_secret(name=f"{DEFAULT_WORKSPACE}/secrets/non-existing")
    assert exc.value.status == http.HTTPStatus.NOT_FOUND



import http
import json

import pytest

from h2o_secure_store.exception import CustomApiException


def test_update_oauth_client(
    delete_all_oauth_clients_before_after,
    super_admin_oauth_client_client,
    oauth_client1,
):
    assert oauth_client1.client_id == "client1"
    assert oauth_client1.display_name == ""
    assert oauth_client1.extra_scopes == []
    assert oauth_client1.refresh_disabled is False
    assert oauth_client1.login_principal_claim == "preferred_username"

    oauth_client1.client_id = "new-client1"
    oauth_client1.display_name = "new display name"
    oauth_client1.extra_scopes = ["alpha", "beta"]
    oauth_client1.refresh_disabled = True
    oauth_client1.login_principal_claim = "new-login-principal-claim"

    # Update all update-able fields.
    updated = super_admin_oauth_client_client.update_oauth_client(
        oauth_client=oauth_client1,
    )

    assert updated.client_id == "client1"
    assert updated.display_name == "new display name"
    assert updated.extra_scopes == ["alpha", "beta"]
    assert updated.refresh_disabled is True
    assert updated.login_principal_claim == "new-login-principal-claim"

    # Update specified fields.
    updated.client_id = "new-client2"
    updated.display_name = "new display name 2"
    updated.extra_scopes = ["alpha2", "beta2"]
    updated.refresh_disabled = False
    updated.login_principal_claim = "new-login-principal-claim2"
    updated_again = super_admin_oauth_client_client.update_oauth_client(
        oauth_client=updated,
        update_mask="display_name,login_principal_claim",
    )

    assert updated_again.client_id == "client1"
    assert updated_again.display_name == "new display name 2"
    assert updated_again.extra_scopes == ["alpha", "beta"]
    assert updated_again.refresh_disabled is True
    assert updated_again.login_principal_claim == "new-login-principal-claim2"


def test_update_oauth_client_not_found(
    delete_all_oauth_clients_before_after,
    super_admin_oauth_client_client,
    oauth_client1,
):
    oauth_client1.oauth_client_id = "whatever"
    oauth_client1.name = "oauthClients/whatever"
    with pytest.raises(CustomApiException) as exc:
        super_admin_oauth_client_client.update_oauth_client(
            oauth_client=oauth_client1
        )
    assert exc.value.status == http.HTTPStatus.NOT_FOUND


def test_update_oauth_client_validation(
    delete_all_oauth_clients_before_after,
    super_admin_oauth_client_client,
    oauth_client1,
):
    assert oauth_client1.extra_scopes == []
    oauth_client1.extra_scopes = [" email"]

    with pytest.raises(CustomApiException) as exc:
        super_admin_oauth_client_client.update_oauth_client(
            oauth_client=oauth_client1,
        )
    assert exc.value.status == http.HTTPStatus.BAD_REQUEST
    assert 'extraScope " email" contains whitespace' in json.loads(exc.value.body)["message"]


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/securestore/v1/secret.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"ai/h2o/securestore/v1/secret.proto\x12\x15\x61i.h2o.securestore.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8f\x06\n\x06Secret\x12\x19\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x08\x03R\x04name\x12?\n\x05state\x18\x02 \x01(\x0e\x32#.ai.h2o.securestore.v1.Secret.StateB\x04\xe2\x41\x01\x03R\x05state\x12\x1e\n\x07\x63reator\x18\x03 \x01(\tB\x04\xe2\x41\x01\x03R\x07\x63reator\x12\x1f\n\x07\x64\x65leter\x18\x04 \x01(\tB\x05\xe2\x41\x02\x01\x03R\x07\x64\x65leter\x12\x41\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12G\n\x0b\x64\x65lete_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x01\x03H\x00R\ndeleteTime\x88\x01\x01\x12\x45\n\npurge_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x01\x03H\x01R\tpurgeTime\x88\x01\x01\x12\x16\n\x03uid\x18\x08 \x01(\tB\x04\xe2\x41\x01\x03R\x03uid\x12V\n\x0b\x61nnotations\x18\t \x03(\x0b\x32..ai.h2o.securestore.v1.Secret.AnnotationsEntryB\x04\xe2\x41\x01\x01R\x0b\x61nnotations\x12\'\n\x0c\x64isplay_name\x18\n \x01(\tB\x04\xe2\x41\x01\x01R\x0b\x64isplayName\x1a>\n\x10\x41nnotationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"C\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x10\n\x0cSTATE_ACTIVE\x10\x01\x12\x11\n\rSTATE_DELETED\x10\x02:X\xea\x41U\n\x19securestore.h2o.ai/Secret\x12\'workspaces/{workspace}/secrets/{secret}*\x07secrets2\x06secretB\x0e\n\x0c_delete_timeB\r\n\x0b_purge_timeB\xe6\x01\n\x19\x63om.ai.h2o.securestore.v1B\x0bSecretProtoP\x01ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\xa2\x02\x03\x41HS\xaa\x02\x15\x41i.H2o.Securestore.V1\xca\x02\x15\x41i\\H2o\\Securestore\\V1\xe2\x02!Ai\\H2o\\Securestore\\V1\\GPBMetadata\xea\x02\x18\x41i::H2o::Securestore::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.h2o.securestore.v1.secret_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.ai.h2o.securestore.v1B\013SecretProtoP\001ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\242\002\003AHS\252\002\025Ai.H2o.Securestore.V1\312\002\025Ai\\H2o\\Securestore\\V1\342\002!Ai\\H2o\\Securestore\\V1\\GPBMetadata\352\002\030Ai::H2o::Securestore::V1'
  _globals['_SECRET_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_SECRET_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_SECRET'].fields_by_name['name']._loaded_options = None
  _globals['_SECRET'].fields_by_name['name']._serialized_options = b'\342A\002\010\003'
  _globals['_SECRET'].fields_by_name['state']._loaded_options = None
  _globals['_SECRET'].fields_by_name['state']._serialized_options = b'\342A\001\003'
  _globals['_SECRET'].fields_by_name['creator']._loaded_options = None
  _globals['_SECRET'].fields_by_name['creator']._serialized_options = b'\342A\001\003'
  _globals['_SECRET'].fields_by_name['deleter']._loaded_options = None
  _globals['_SECRET'].fields_by_name['deleter']._serialized_options = b'\342A\002\001\003'
  _globals['_SECRET'].fields_by_name['create_time']._loaded_options = None
  _globals['_SECRET'].fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _globals['_SECRET'].fields_by_name['delete_time']._loaded_options = None
  _globals['_SECRET'].fields_by_name['delete_time']._serialized_options = b'\342A\002\001\003'
  _globals['_SECRET'].fields_by_name['purge_time']._loaded_options = None
  _globals['_SECRET'].fields_by_name['purge_time']._serialized_options = b'\342A\002\001\003'
  _globals['_SECRET'].fields_by_name['uid']._loaded_options = None
  _globals['_SECRET'].fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _globals['_SECRET'].fields_by_name['annotations']._loaded_options = None
  _globals['_SECRET'].fields_by_name['annotations']._serialized_options = b'\342A\001\001'
  _globals['_SECRET'].fields_by_name['display_name']._loaded_options = None
  _globals['_SECRET'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_SECRET']._loaded_options = None
  _globals['_SECRET']._serialized_options = b'\352AU\n\031securestore.h2o.ai/Secret\022\'workspaces/{workspace}/secrets/{secret}*\007secrets2\006secret'
  _globals['_SECRET']._serialized_start=155
  _globals['_SECRET']._serialized_end=938
  _globals['_SECRET_ANNOTATIONSENTRY']._serialized_start=686
  _globals['_SECRET_ANNOTATIONSENTRY']._serialized_end=748
  _globals['_SECRET_STATE']._serialized_start=750
  _globals['_SECRET_STATE']._serialized_end=817
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from h2o_secure_store.gen.ai.h2o.securestore.v1 import secret_version_service_pb2 as ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2


class SecretVersionServiceStub(object):
    """SecretVersionService manages SecretVersion resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateSecretVersion = channel.unary_unary(
                '/ai.h2o.securestore.v1.SecretVersionService/CreateSecretVersion',
                request_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.CreateSecretVersionRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.CreateSecretVersionResponse.FromString,
                _registered_method=True)
        self.GetSecretVersion = channel.unary_unary(
                '/ai.h2o.securestore.v1.SecretVersionService/GetSecretVersion',
                request_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.GetSecretVersionRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.GetSecretVersionResponse.FromString,
                _registered_method=True)
        self.ListSecretVersions = channel.unary_unary(
                '/ai.h2o.securestore.v1.SecretVersionService/ListSecretVersions',
                request_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.ListSecretVersionsRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.ListSecretVersionsResponse.FromString,
                _registered_method=True)
        self.RevealSecretVersionValue = channel.unary_unary(
                '/ai.h2o.securestore.v1.SecretVersionService/RevealSecretVersionValue',
                request_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.RevealSecretVersionValueRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.RevealSecretVersionValueResponse.FromString,
                _registered_method=True)


class SecretVersionServiceServicer(object):
    """SecretVersionService manages SecretVersion resources.
    """

    def CreateSecretVersion(self, request, context):
        """Creates a new SecretVersion containing secret data.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSecretVersion(self, request, context):
        """Gets metadata for a SecretVersion.
        "workspaces/*/secrets/*/versions/latest" is an alias for the most recently created SecretVersion.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSecretVersions(self, request, context):
        """Lists SecretVersions. This call does not return secret data.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevealSecretVersionValue(self, request, context):
        """Reveals the value of a SecretVersion. This call returns the secret data.
        "workspaces/*/secrets/*/versions/latest" is an alias for the most recently created SecretVersion.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SecretVersionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateSecretVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSecretVersion,
                    request_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.CreateSecretVersionRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.CreateSecretVersionResponse.SerializeToString,
            ),
            'GetSecretVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSecretVersion,
                    request_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.GetSecretVersionRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.GetSecretVersionResponse.SerializeToString,
            ),
            'ListSecretVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSecretVersions,
                    request_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.ListSecretVersionsRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.ListSecretVersionsResponse.SerializeToString,
            ),
            'RevealSecretVersionValue': grpc.unary_unary_rpc_method_handler(
                    servicer.RevealSecretVersionValue,
                    request_deserializer=ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.RevealSecretVersionValueRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.RevealSecretVersionValueResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ai.h2o.securestore.v1.SecretVersionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SecretVersionService(object):
    """SecretVersionService manages SecretVersion resources.
    """

    @staticmethod
    def CreateSecretVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.h2o.securestore.v1.SecretVersionService/CreateSecretVersion',
            ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.CreateSecretVersionRequest.SerializeToString,
            ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.CreateSecretVersionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSecretVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.h2o.securestore.v1.SecretVersionService/GetSecretVersion',
            ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.GetSecretVersionRequest.SerializeToString,
            ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.GetSecretVersionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListSecretVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.h2o.securestore.v1.SecretVersionService/ListSecretVersions',
            ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.ListSecretVersionsRequest.SerializeToString,
            ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.ListSecretVersionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RevealSecretVersionValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.h2o.securestore.v1.SecretVersionService/RevealSecretVersionValue',
            ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.RevealSecretVersionValueRequest.SerializeToString,
            ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__service__pb2.RevealSecretVersionValueResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from h2o_secure_store.gen.ai.h2o.securestore.v1 import secret_version_pb2 as _secret_version_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.api import resource_pb2 as _resource_pb2
from google.api import client_pb2 as _client_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateSecretVersionRequest(_message.Message):
    __slots__ = ("parent", "secret_version")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    SECRET_VERSION_FIELD_NUMBER: _ClassVar[int]
    parent: str
    secret_version: _secret_version_pb2.SecretVersion
    def __init__(self, parent: _Optional[str] = ..., secret_version: _Optional[_Union[_secret_version_pb2.SecretVersion, _Mapping]] = ...) -> None: ...

class CreateSecretVersionResponse(_message.Message):
    __slots__ = ("secret_version",)
    SECRET_VERSION_FIELD_NUMBER: _ClassVar[int]
    secret_version: _secret_version_pb2.SecretVersion
    def __init__(self, secret_version: _Optional[_Union[_secret_version_pb2.SecretVersion, _Mapping]] = ...) -> None: ...

class GetSecretVersionRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class GetSecretVersionResponse(_message.Message):
    __slots__ = ("secret_version",)
    SECRET_VERSION_FIELD_NUMBER: _ClassVar[int]
    secret_version: _secret_version_pb2.SecretVersion
    def __init__(self, secret_version: _Optional[_Union[_secret_version_pb2.SecretVersion, _Mapping]] = ...) -> None: ...

class ListSecretVersionsRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class ListSecretVersionsResponse(_message.Message):
    __slots__ = ("secret_versions", "next_page_token", "total_size")
    SECRET_VERSIONS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    secret_versions: _containers.RepeatedCompositeFieldContainer[_secret_version_pb2.SecretVersion]
    next_page_token: str
    total_size: int
    def __init__(self, secret_versions: _Optional[_Iterable[_Union[_secret_version_pb2.SecretVersion, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class RevealSecretVersionValueRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class RevealSecretVersionValueResponse(_message.Message):
    __slots__ = ("name", "value")
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: bytes
    def __init__(self, name: _Optional[str] = ..., value: _Optional[bytes] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/securestore/v1/secret_version_service.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from h2o_secure_store.gen.ai.h2o.securestore.v1 import secret_version_pb2 as ai_dot_h2o_dot_securestore_dot_v1_dot_secret__version__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2ai/h2o/securestore/v1/secret_version_service.proto\x12\x15\x61i.h2o.securestore.v1\x1a*ai/h2o/securestore/v1/secret_version.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/api/resource.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\"\xb2\x01\n\x1a\x43reateSecretVersionRequest\x12\x41\n\x06parent\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\x12 securestore.h2o.ai/SecretVersionR\x06parent\x12Q\n\x0esecret_version\x18\x02 \x01(\x0b\x32$.ai.h2o.securestore.v1.SecretVersionB\x04\xe2\x41\x01\x02R\rsecretVersion\"j\n\x1b\x43reateSecretVersionResponse\x12K\n\x0esecret_version\x18\x01 \x01(\x0b\x32$.ai.h2o.securestore.v1.SecretVersionR\rsecretVersion\"X\n\x17GetSecretVersionRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n securestore.h2o.ai/SecretVersionR\x04name\"g\n\x18GetSecretVersionResponse\x12K\n\x0esecret_version\x18\x01 \x01(\x0b\x32$.ai.h2o.securestore.v1.SecretVersionR\rsecretVersion\"\xa6\x01\n\x19ListSecretVersionsRequest\x12\x41\n\x06parent\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\x12 securestore.h2o.ai/SecretVersionR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\xb2\x01\n\x1aListSecretVersionsResponse\x12M\n\x0fsecret_versions\x18\x01 \x03(\x0b\x32$.ai.h2o.securestore.v1.SecretVersionR\x0esecretVersions\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"`\n\x1fRevealSecretVersionValueRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n securestore.h2o.ai/SecretVersionR\x04name\"L\n RevealSecretVersionValueResponse\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value2\xb1\x06\n\x14SecretVersionService\x12\xda\x01\n\x13\x43reateSecretVersion\x12\x31.ai.h2o.securestore.v1.CreateSecretVersionRequest\x1a\x32.ai.h2o.securestore.v1.CreateSecretVersionResponse\"\\\xda\x41\x15parent,secret_version\x82\xd3\xe4\x93\x02>\",/v1/{parent=workspaces/*/secrets/*}/versions:\x0esecret_version\x12\xb0\x01\n\x10GetSecretVersion\x12..ai.h2o.securestore.v1.GetSecretVersionRequest\x1a/.ai.h2o.securestore.v1.GetSecretVersionResponse\";\xda\x41\x04name\x82\xd3\xe4\x93\x02.\x12,/v1/{name=workspaces/*/secrets/*/versions/*}\x12\xb8\x01\n\x12ListSecretVersions\x12\x30.ai.h2o.securestore.v1.ListSecretVersionsRequest\x1a\x31.ai.h2o.securestore.v1.ListSecretVersionsResponse\"=\xda\x41\x06parent\x82\xd3\xe4\x93\x02.\x12,/v1/{parent=workspaces/*/secrets/*}/versions\x12\xcd\x01\n\x18RevealSecretVersionValue\x12\x36.ai.h2o.securestore.v1.RevealSecretVersionValueRequest\x1a\x37.ai.h2o.securestore.v1.RevealSecretVersionValueResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/v1/{name=workspaces/*/secrets/*/versions/*}:revealValueB\xf4\x01\n\x19\x63om.ai.h2o.securestore.v1B\x19SecretVersionServiceProtoP\x01ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\xa2\x02\x03\x41HS\xaa\x02\x15\x41i.H2o.Securestore.V1\xca\x02\x15\x41i\\H2o\\Securestore\\V1\xe2\x02!Ai\\H2o\\Securestore\\V1\\GPBMetadata\xea\x02\x18\x41i::H2o::Securestore::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.h2o.securestore.v1.secret_version_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.ai.h2o.securestore.v1B\031SecretVersionServiceProtoP\001ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\242\002\003AHS\252\002\025Ai.H2o.Securestore.V1\312\002\025Ai\\H2o\\Securestore\\V1\342\002!Ai\\H2o\\Securestore\\V1\\GPBMetadata\352\002\030Ai::H2o::Securestore::V1'
  _globals['_CREATESECRETVERSIONREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATESECRETVERSIONREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\"\022 securestore.h2o.ai/SecretVersion'
  _globals['_CREATESECRETVERSIONREQUEST'].fields_by_name['secret_version']._loaded_options = None
  _globals['_CREATESECRETVERSIONREQUEST'].fields_by_name['secret_version']._serialized_options = b'\342A\001\002'
  _globals['_GETSECRETVERSIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETSECRETVERSIONREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n securestore.h2o.ai/SecretVersion'
  _globals['_LISTSECRETVERSIONSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTSECRETVERSIONSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\"\022 securestore.h2o.ai/SecretVersion'
  _globals['_LISTSECRETVERSIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSECRETVERSIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTSECRETVERSIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSECRETVERSIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_REVEALSECRETVERSIONVALUEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_REVEALSECRETVERSIONVALUEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n securestore.h2o.ai/SecretVersion'
  _globals['_SECRETVERSIONSERVICE'].methods_by_name['CreateSecretVersion']._loaded_options = None
  _globals['_SECRETVERSIONSERVICE'].methods_by_name['CreateSecretVersion']._serialized_options = b'\332A\025parent,secret_version\202\323\344\223\002>\",/v1/{parent=workspaces/*/secrets/*}/versions:\016secret_version'
  _globals['_SECRETVERSIONSERVICE'].methods_by_name['GetSecretVersion']._loaded_options = None
  _globals['_SECRETVERSIONSERVICE'].methods_by_name['GetSecretVersion']._serialized_options = b'\332A\004name\202\323\344\223\002.\022,/v1/{name=workspaces/*/secrets/*/versions/*}'
  _globals['_SECRETVERSIONSERVICE'].methods_by_name['ListSecretVersions']._loaded_options = None
  _globals['_SECRETVERSIONSERVICE'].methods_by_name['ListSecretVersions']._serialized_options = b'\332A\006parent\202\323\344\223\002.\022,/v1/{parent=workspaces/*/secrets/*}/versions'
  _globals['_SECRETVERSIONSERVICE'].methods_by_name['RevealSecretVersionValue']._loaded_options = None
  _globals['_SECRETVERSIONSERVICE'].methods_by_name['RevealSecretVersionValue']._serialized_options = b'\202\323\344\223\002:\0228/v1/{name=workspaces/*/secrets/*/versions/*}:revealValue'
  _globals['_CREATESECRETVERSIONREQUEST']._serialized_start=237
  _globals['_CREATESECRETVERSIONREQUEST']._serialized_end=415
  _globals['_CREATESECRETVERSIONRESPONSE']._serialized_start=417
  _globals['_CREATESECRETVERSIONRESPONSE']._serialized_end=523
  _globals['_GETSECRETVERSIONREQUEST']._serialized_start=525
  _globals['_GETSECRETVERSIONREQUEST']._serialized_end=613
  _globals['_GETSECRETVERSIONRESPONSE']._serialized_start=615
  _globals['_GETSECRETVERSIONRESPONSE']._serialized_end=718
  _globals['_LISTSECRETVERSIONSREQUEST']._serialized_start=721
  _globals['_LISTSECRETVERSIONSREQUEST']._serialized_end=887
  _globals['_LISTSECRETVERSIONSRESPONSE']._serialized_start=890
  _globals['_LISTSECRETVERSIONSRESPONSE']._serialized_end=1068
  _globals['_REVEALSECRETVERSIONVALUEREQUEST']._serialized_start=1070
  _globals['_REVEALSECRETVERSIONVALUEREQUEST']._serialized_end=1166
  _globals['_REVEALSECRETVERSIONVALUERESPONSE']._serialized_start=1168
  _globals['_REVEALSECRETVERSIONVALUERESPONSE']._serialized_end=1244
  _globals['_SECRETVERSIONSERVICE']._serialized_start=1247
  _globals['_SECRETVERSIONSERVICE']._serialized_end=2064
# @@protoc_insertion_point(module_scope)



from typing import Dict
from typing import List
from typing import Optional

from h2o_secure_store.clients.auth.token_api_client import TokenApiClient
from h2o_secure_store.clients.connection_config import ConnectionConfig
from h2o_secure_store.clients.secret.page import SecretsPage
from h2o_secure_store.clients.secret.secret import Secret
from h2o_secure_store.clients.secret.secret import from_api_object
from h2o_secure_store.exception import CustomApiException
from h2o_secure_store.gen import ApiException
from h2o_secure_store.gen import Configuration
from h2o_secure_store.gen.api.secret_service_api import SecretServiceApi
from h2o_secure_store.gen.model.v1_list_secrets_response import V1ListSecretsResponse
from h2o_secure_store.gen.model.v1_secret import V1Secret


class SecretClient:
    """SecretClient manages Secrets."""

    def __init__(
            self,
            connection_config: ConnectionConfig,
            verify_ssl: bool = True,
            ssl_ca_cert: Optional[str] = None,
    ):
        configuration = Configuration(host=connection_config.server_url)
        configuration.verify_ssl = verify_ssl
        configuration.ssl_ca_cert = ssl_ca_cert

        with TokenApiClient(
                configuration, connection_config.token_provider
        ) as api_client:
            self.api_instance = SecretServiceApi(api_client)

    def create_secret(
            self,
            parent: str,
            secret_id: str = "",
            display_name: str = "",
            annotations: Dict[str, str] = None,
    ) -> Secret:
        """Creates a Secret.

        Args:
            parent (str): The resource name of the workspace to associate with the Secret.
                Format is `workspaces/*`.
            secret_id (str, optional): The ID to use for the Secret, which will become the final component
                of the secret's resource name.
                If left unspecified, the server will generate one.
                This value must:
                - contain 1-63 characters
                - contain only lowercase alphanumeric characters or hyphen ('-')
                - start with an alphabetic character
                - end with an alphanumeric character
            display_name (str, optional): Human-readable name of the Secret. Does not have to be unique.
            annotations (Dict[str, str], optional): Additional arbitrary metadata associated with the Secret. Annotations are key/value pairs.

        Returns:
            Secret: Secret object.
        """
        created_api_object: V1Secret

        try:
            created_api_object = self.api_instance.secret_service_create_secret(
                parent=parent,
                secret=Secret(
                    display_name=display_name,
                    annotations=annotations if annotations is not None else {},
                ).to_api_object(),
                secret_id=secret_id,
            ).secret
        except ApiException as e:
            raise CustomApiException(e)
        return from_api_object(api_object=created_api_object)

    def get_secret(self, name: str) -> Secret:
        """Returns a Secret.

        Args:
            name (str): The resource name of the Secret. Format is `workspaces/*/secrets/*`.

        Returns:
            Secret: Secret object.
        """
        api_object: V1Secret

        try:
            api_object = self.api_instance.secret_service_get_secret(
                name_1=name
            ).secret
        except ApiException as e:
            raise CustomApiException(e)

        return from_api_object(api_object=api_object)

    def list_secrets(
            self,
            parent: str,
            page_size: int = 0,
            page_token: str = "",
            show_deleted: bool = False,
    ) -> SecretsPage:
        """Lists Secrets.

        Args:
            parent (str): The resource name of the workspace from which to list Secrets.
                Format is `workspaces/*`.
            page_size (int): Maximum number of Secrets to return in a response.
                If unspecified (or set to 0), at most 50 Secrets will be returned.
                The maximum value is 1000; values above 1000 will be coerced to 1000.
            page_token (str): Page token.
                Leave unset to receive the initial page.
                To list any subsequent pages use the value of 'next_page_token' returned from the SecretsPage.
            show_deleted (bool): If set to true, include deleted Secrets in the response.

        Returns:
            SecretsPage: SecretsPage object.
        """
        list_response: V1ListSecretsResponse

        try:
            list_response = (
                self.api_instance.secret_service_list_secrets(
                    parent=parent,
                    page_size=page_size,
                    page_token=page_token,
                    show_deleted=show_deleted,
                )
            )
        except ApiException as e:
            raise CustomApiException(e)

        return SecretsPage(list_response)

    def list_all_secrets(self, parent: str, show_deleted: bool = False) -> List[Secret]:
        """ List all Secrets.

        Args:
            parent (str): The resource name of the workspace from which to list Secrets.
                Format is `workspaces/*`.
            show_deleted (bool): If set to true, include deleted Secrets in the response.

        Returns:
            List of Secret.
        """
        all_secrets: List[Secret] = []
        next_page_token = ""
        while True:
            secret_list = self.list_secrets(
                parent=parent,
                page_size=0,
                page_token=next_page_token,
                show_deleted=show_deleted,
            )
            all_secrets = all_secrets + secret_list.secrets
            next_page_token = secret_list.next_page_token
            if next_page_token == "":
                break

        return all_secrets

    def delete_secret(self, name: str) -> Secret:
        """Deletes a Secret and the child SecretVersions.
        A deleted secret is purged after 30 days but can be restored using the undelete method.

        Args:
            name (str): The resource name of the Secret. Format is `workspaces/*/secrets/*`.
        """
        api_object: V1Secret

        try:
            api_object = self.api_instance.secret_service_delete_secret(
                name_1=name
            ).secret
        except ApiException as e:
            raise CustomApiException(e)

        return from_api_object(api_object=api_object)

    def undelete_secret(self, name: str) -> Secret:
        """Undeletes a deleted Secret and the child SecretVersions.

        Args:
            name (str): The resource name of the Secret. Format is `workspaces/*/secrets/*`.
        """
        api_object: V1Secret

        try:
            api_object = self.api_instance.secret_service_undelete_secret(
                name=name,
                body={},
            ).secret
        except ApiException as e:
            raise CustomApiException(e)

        return from_api_object(api_object=api_object)

    def delete_all_secrets(self, parent: str) -> None:
        """Delete all Secrets."""
        for n in self.list_all_secrets(parent=parent, show_deleted=False):
            self.delete_secret(name=n.name)




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/securestore/v1/oauth_client.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ai/h2o/securestore/v1/oauth_client.proto\x12\x15\x61i.h2o.securestore.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xed\x06\n\x0bOAuthClient\x12\x19\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x08\x03R\x04name\x12\'\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x0b\x64isplayName\x12\x1d\n\x06issuer\x18\x03 \x01(\tB\x05\xe2\x41\x02\x02\x05R\x06issuer\x12\"\n\tclient_id\x18\x04 \x01(\tB\x05\xe2\x41\x02\x02\x05R\x08\x63lientId\x12*\n\rclient_secret\x18\x05 \x01(\tB\x05\xe2\x41\x02\x01\x04R\x0c\x63lientSecret\x12\x30\n\x11\x63lient_secret_set\x18\x06 \x01(\x08\x42\x04\xe2\x41\x01\x03R\x0f\x63lientSecretSet\x12<\n\x16\x61uthorization_endpoint\x18\x07 \x01(\tB\x05\xe2\x41\x02\x01\x07R\x15\x61uthorizationEndpoint\x12,\n\x0etoken_endpoint\x18\x08 \x01(\tB\x05\xe2\x41\x02\x01\x07R\rtokenEndpoint\x12\'\n\x0c\x65xtra_scopes\x18\t \x03(\tB\x04\xe2\x41\x01\x01R\x0b\x65xtraScopes\x12/\n\x10refresh_disabled\x18\n \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0frefreshDisabled\x12\x39\n\x15login_principal_claim\x18\x0b \x01(\tB\x05\xe2\x41\x02\x01\x07R\x13loginPrincipalClaim\x12\'\n\x0c\x63\x61llback_uri\x18\x0c \x01(\tB\x04\xe2\x41\x01\x03R\x0b\x63\x61llbackUri\x12\x1e\n\x07\x63reator\x18\r \x01(\tB\x04\xe2\x41\x01\x03R\x07\x63reator\x12\x1f\n\x07updater\x18\x0e \x01(\tB\x05\xe2\x41\x02\x01\x03R\x07updater\x12\x41\n\x0b\x63reate_time\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12G\n\x0bupdate_time\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x01\x03H\x00R\nupdateTime\x88\x01\x01\x12\x16\n\x03uid\x18\x11 \x01(\tB\x04\xe2\x41\x01\x03R\x03uid:Z\xea\x41W\n\x1esecurestore.h2o.ai/OAuthClient\x12\x1aoauthClients/{oauthClient}*\x0coauthClients2\x0boauthClientB\x0e\n\x0c_update_timeB\xeb\x01\n\x19\x63om.ai.h2o.securestore.v1B\x10OauthClientProtoP\x01ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\xa2\x02\x03\x41HS\xaa\x02\x15\x41i.H2o.Securestore.V1\xca\x02\x15\x41i\\H2o\\Securestore\\V1\xe2\x02!Ai\\H2o\\Securestore\\V1\\GPBMetadata\xea\x02\x18\x41i::H2o::Securestore::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.h2o.securestore.v1.oauth_client_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.ai.h2o.securestore.v1B\020OauthClientProtoP\001ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\242\002\003AHS\252\002\025Ai.H2o.Securestore.V1\312\002\025Ai\\H2o\\Securestore\\V1\342\002!Ai\\H2o\\Securestore\\V1\\GPBMetadata\352\002\030Ai::H2o::Securestore::V1'
  _globals['_OAUTHCLIENT'].fields_by_name['name']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['name']._serialized_options = b'\342A\002\010\003'
  _globals['_OAUTHCLIENT'].fields_by_name['display_name']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_OAUTHCLIENT'].fields_by_name['issuer']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['issuer']._serialized_options = b'\342A\002\002\005'
  _globals['_OAUTHCLIENT'].fields_by_name['client_id']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['client_id']._serialized_options = b'\342A\002\002\005'
  _globals['_OAUTHCLIENT'].fields_by_name['client_secret']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['client_secret']._serialized_options = b'\342A\002\001\004'
  _globals['_OAUTHCLIENT'].fields_by_name['client_secret_set']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['client_secret_set']._serialized_options = b'\342A\001\003'
  _globals['_OAUTHCLIENT'].fields_by_name['authorization_endpoint']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['authorization_endpoint']._serialized_options = b'\342A\002\001\007'
  _globals['_OAUTHCLIENT'].fields_by_name['token_endpoint']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['token_endpoint']._serialized_options = b'\342A\002\001\007'
  _globals['_OAUTHCLIENT'].fields_by_name['extra_scopes']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['extra_scopes']._serialized_options = b'\342A\001\001'
  _globals['_OAUTHCLIENT'].fields_by_name['refresh_disabled']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['refresh_disabled']._serialized_options = b'\342A\001\001'
  _globals['_OAUTHCLIENT'].fields_by_name['login_principal_claim']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['login_principal_claim']._serialized_options = b'\342A\002\001\007'
  _globals['_OAUTHCLIENT'].fields_by_name['callback_uri']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['callback_uri']._serialized_options = b'\342A\001\003'
  _globals['_OAUTHCLIENT'].fields_by_name['creator']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['creator']._serialized_options = b'\342A\001\003'
  _globals['_OAUTHCLIENT'].fields_by_name['updater']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['updater']._serialized_options = b'\342A\002\001\003'
  _globals['_OAUTHCLIENT'].fields_by_name['create_time']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _globals['_OAUTHCLIENT'].fields_by_name['update_time']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['update_time']._serialized_options = b'\342A\002\001\003'
  _globals['_OAUTHCLIENT'].fields_by_name['uid']._loaded_options = None
  _globals['_OAUTHCLIENT'].fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _globals['_OAUTHCLIENT']._loaded_options = None
  _globals['_OAUTHCLIENT']._serialized_options = b'\352AW\n\036securestore.h2o.ai/OAuthClient\022\032oauthClients/{oauthClient}*\014oauthClients2\013oauthClient'
  _globals['_OAUTHCLIENT']._serialized_start=161
  _globals['_OAUTHCLIENT']._serialized_end=1038
# @@protoc_insertion_point(module_scope)



from h2o_secure_store.clients.oauth_client.client import OAuthClientClient
from h2o_secure_store.clients.token_source.token_source import TokenSource


def test_invalidate_token_sources(
        delete_all_token_sources_before_after,
        token_source1: TokenSource,
        super_admin_oauth_client_client: OAuthClientClient,
):
    # Cannot test invalidating token sources, only verify that it doesn't throw an error
    super_admin_oauth_client_client.invalidate_token_sources(token_source1.oauth_client_id)



import pprint
from datetime import datetime
from typing import List
from typing import Optional

from h2o_secure_store.gen.model.o_auth_client_resource import OAuthClientResource
from h2o_secure_store.gen.model.v1_o_auth_client import V1OAuthClient


class OAuthClient:
    def __init__(
        self,
        issuer: str,
        client_id: str,
        name: str,
        display_name: str,
        client_secret: str,
        client_secret_set: bool,
        authorization_endpoint: str,
        token_endpoint: str,
        extra_scopes: List[str],
        refresh_disabled: bool,
        login_principal_claim: str,
        callback_uri: str,
        creator: str,
        updater: str,
        uid: str,
        create_time: datetime,
        update_time: Optional[datetime] = None,
    ):
        self.issuer = issuer
        self.client_id = client_id
        self.name = name
        self.display_name = display_name
        self.client_secret = client_secret
        self.client_secret_set = client_secret_set
        self.authorization_endpoint = authorization_endpoint
        self.token_endpoint = token_endpoint
        self.extra_scopes = extra_scopes
        self.refresh_disabled = refresh_disabled
        self.login_principal_claim = login_principal_claim
        self.callback_uri = callback_uri
        self.creator = creator
        self.updater = updater
        self.uid = uid
        self.create_time = create_time
        self.update_time = update_time

        self.oauth_client_id = ""
        if name:
            self.oauth_client_id = self.name.split("/")[1]

    def __repr__(self) -> str:
        return pprint.pformat(self.__dict__)

    def to_api_object(self) -> V1OAuthClient:
        return V1OAuthClient(
            issuer=self.issuer,
            client_id=self.client_id,
            name=self.name,
            display_name=self.display_name,
            client_secret=self.client_secret,
            client_secret_set=self.client_secret_set,
            authorization_endpoint=self.authorization_endpoint,
            token_endpoint=self.token_endpoint,
            extra_scopes=self.extra_scopes,
            refresh_disabled=self.refresh_disabled,
            login_principal_claim=self.login_principal_claim,
            callback_uri=self.callback_uri,
            creator=self.creator,
            updater=self.updater,
            uid=self.uid,
            create_time=self.create_time,
            update_time=self.update_time,
        )

    def to_resource(self) -> OAuthClientResource:
        # This class (OAuthClientResource) is required by Update method.
        # Need to create this instance via protected method _from_openapi_data due to the generated code.
        return OAuthClientResource._from_openapi_data(
            issuer=self.issuer,
            client_id=self.client_id,
            display_name=self.display_name,
            client_secret=self.client_secret,
            client_secret_set=self.client_secret_set,
            authorization_endpoint=self.authorization_endpoint,
            token_endpoint=self.token_endpoint,
            extra_scopes=self.extra_scopes,
            refresh_disabled=self.refresh_disabled,
            login_principal_claim=self.login_principal_claim,
            callback_uri=self.callback_uri,
            creator=self.creator,
            updater=self.updater,
            uid=self.uid,
            create_time=self.create_time,
            update_time=self.update_time,
        )


def from_api_object(api_object: V1OAuthClient) -> OAuthClient:
    return OAuthClient(
        issuer=api_object.issuer,
        client_id=api_object.client_id,
        name=api_object.name,
        display_name=api_object.display_name,
        client_secret=api_object.client_secret,
        client_secret_set=api_object.client_secret_set,
        authorization_endpoint=api_object.authorization_endpoint,
        token_endpoint=api_object.token_endpoint,
        extra_scopes=api_object.extra_scopes,
        refresh_disabled=api_object.refresh_disabled,
        login_principal_claim=api_object.login_principal_claim,
        callback_uri=api_object.callback_uri,
        creator=api_object.creator,
        updater=api_object.updater,
        uid=api_object.uid,
        create_time=api_object.create_time,
        update_time=api_object.update_time,
    )
